@@ -2,10 +2,10 @@
 
 # Check that an index vector specified by the user is ok to index an object.
 # We want to preclude confusing R messages or behaviour later.
-# An example is when max(index) > len(object) which quietly returns NA
-# and can cause confusing downstream behaviour.
-# This returns a vector suitable for indexing into object (will be identical
-# to index unless index is a character vector).
+# An example is when max(index) > length(object) which quietly
+# returns NA and can cause confusing downstream behaviour.
+# This returns a vector suitable for indexing into object (will
+# be identical to index unless index is a character vector).
 #
 # If index is a character vector, then regex matching is used against
 # the names in the object, and an integer vector is returned.
@@ -13,41 +13,42 @@
 check.index <- function(index, index.name, object,
     colnames        = NULL,
     is.col.index    = FALSE,
-    allow.empty     = FALSE, # if index is char will warn if necessary regardles of allow.empty
-    allow.zeroes    = FALSE,
+    allow.empty     = FALSE, # if index is char will warn if necessary regardless of allow.empty
+    allow.zeros     = FALSE,
     allow.negatives = TRUE,
     allow.dups      = FALSE,
     treat.NA.as.one = FALSE,
     is.degree.spec  = FALSE) # special handling for degree1 and degree2 specs
 {
+    index.name <- quotify.short(index.name, "index", quote="'")
+
     # check that the given index and object can be evaluated
-    try1 <- try(eval(index))
-    if(is.try.error(try1))
+    try <- try(eval(index))
+    if(is.try.err(try))
         stop0("illegal ", index.name)
-    try1 <- try(eval(object))
-    if(is.try.error(try1))
-        stop0("illegal ", deparse(substitute(object)))
+    try <- try(eval(object))
+    if(is.try.err(try))
+        stop0("illegal ", quotify.short(object, quote="'"))
 
     is.col.index    <- check.boolean(is.col.index)
     allow.empty     <- check.boolean(allow.empty)
-    allow.zeroes    <- check.boolean(allow.zeroes)
+    allow.zeros     <- check.boolean(allow.zeros)
     allow.negatives <- check.boolean(allow.negatives)
     allow.dups      <- check.boolean(allow.dups)
     treat.NA.as.one <- check.boolean(treat.NA.as.one)
 
     if(is.null(index)) {
         if(!allow.empty)
-           stop0("\"", index.name,
-                 "\" is NULL and cannot be used as an index")
+           stop0(index.name, " is NULL and cannot be used as an index")
         return(NULL)
     }
     if(treat.NA.as.one && (length(index) == 1 && is.na(index)[1]))
         index <- 1
-    if(any(is.na(index)))
-        stop0("NA in \"", index.name, "\"")
+    if(anyNA(index))
+        stop0("NA in ", index.name)
     if(NROW(index) != 1 && NCOL(index) != 1)
-        stop0("\"", index.name, "\" must be a vector not a matrix ",
-              "(\"", index.name, "\" has dimensions ",
+        stop0(index.name, " must be a vector not a matrix (",
+              index.name, " has dimensions ",
               NROW(index), " x ", NCOL(index), ")")
 
     len <- get.len(object, is.col.index)
@@ -59,7 +60,7 @@ check.index <- function(index, index.name, object,
         check.logical.index(index, index.name, len, allow.empty)
     else if(is.numeric(index))
         check.numeric.index(index, index.name, len, allow.empty,
-            allow.negatives, allow.dups, allow.zeroes)
+            allow.negatives, allow.dups, allow.zeros, treat.NA.as.one)
     else
         stop0(index.name, " must be an index vector (numeric, logical, or character)")
 }
@@ -67,7 +68,7 @@ get.len <- function(object, is.col.index)
 {
     if(is.col.index)
         len <- NCOL(object) # index is for columns of object
-    else if(is.vector(object))
+    else if(is.null(dim(object)))
         len <- length(object)
     else
         len <- NROW(object) # index is for rows of object
@@ -95,6 +96,7 @@ check.character.index <- function(index, index.name, object, names, len,
                                   is.col.index, allow.empty, is.degree.spec)
 {
     stopifnot(is.character(index))
+    if(!is.character(index))
     # certain regular expressions match everything, even if names not avail
     if(length(index) == 1 && index %in% c("", ".", ".*"))
         return(1:len)
@@ -118,11 +120,12 @@ check.character.index <- function(index, index.name, object, names, len,
         else if(length(dim(object)) == 2) # 2D matrix, degree2
             matches <- c(matchmult(matches, object[,1]), matchmult(matches, object[,2]))
         else
-            stop("that kind of object is not yet supported for ", index.name)
+            stop0("that kind of object is not yet supported for ", index.name)
     }
     new.index <- unique(matches[!is.na(matches)])
     for(name in warning.names)
-        warning0("\"", name, "\" in ", index.name, " does not match any names")
+        warning0("\"", name, "\" in ", unquote(index.name), " does not match any names\n",
+                 "         Available names are ", paste.trunc(quotify(names)))
     new.index
 }
 check.logical.index <- function(index, index.name, len, allow.empty)
@@ -130,13 +133,13 @@ check.logical.index <- function(index, index.name, len, allow.empty)
     stopifnot(is.logical(index))
     if(!allow.empty) {
         if(length(index) == 0)
-            stop0("length(", index.name, ") == 0")
+            stop0("length(", unquote(index.name), ") == 0")
         if(length(index[index == TRUE]) == 0)
-            stop0("\"", index.name, "\" is all FALSE")
+            stop0(index.name, " is all FALSE")
     }
     # note that a single FALSE or TRUE is ok regardless of length(object)
     if(length(index) > len && length(index) != 1) {
-        stop0("logical index \"", index.name, "\" is too long.\n",
+        stop0("logical index ", index.name, " is too long.\n",
               "       Its length is ", length(index),
               " and the max allowed length is ", len)
     }
@@ -144,7 +147,7 @@ check.logical.index <- function(index, index.name, len, allow.empty)
 }
 check.numeric.index <- function(index, index.name, len, allow.empty,
                                 allow.negatives, allow.dups,
-                                allow.zeroes, treat.NA.as.one)
+                                allow.zeros, treat.NA.as.one)
 {
     stopifnot(is.numeric(index))
     if(!allow.empty) {
@@ -152,30 +155,31 @@ check.numeric.index <- function(index, index.name, len, allow.empty,
             stop0(index.name, " is empty, (its length is 0)")
         else if(all(index == 0))
             if(length(index) == 1)
-                stop0("\"", index.name, "\" is 0")
+                stop0(index.name, " is 0")
             else
-                stop0("\"", index.name, "\" is all zeroes")
+                stop0(index.name, " is all zeros")
     }
     if(!is.integral(index))
         stop0(index.name, " is not an integer")
     if(any(index < 0) && any(index > 0))
-        stop0("mixed negative and positive values in \"", index.name, "\"")
-    if(!allow.zeroes && any(index == 0) && length(index) != 1)
-        warning0("zero in \"", index.name, "\"")
+        stop0("mixed negative and positive values in ", index.name)
+    if(!allow.zeros && any(index == 0) && length(index) != 1)
+        warning0("zero in ", index.name)
     if(!allow.negatives && any(index < 0))
-        stop0("negative value in \"", index.name, "\"")
+        stop0("negative value in ", index.name)
     if(!allow.dups && any(duplicated(index)))
-        warning0("duplicates in \"", index.name, "\"")
+        warning0("duplicates in ", index.name)
     if(any(abs(index) > len)) {
-        if(len != 1)
-            stop0("out of range value in \"", index.name,
-                  "\" (allowed index range is 1:",  len, ")")
-        else if(treat.NA.as.one)
-            stop0("out of range value in \"", index.name,
-                  "\", the only legal value is 1 (or NA)")
+        if(length(index) == 1)
+            prefix <- paste0(unquote(index.name), "=", index, " but ")
         else
-            stop0("out of range value in \"", index.name,
-                  "\" (the only legal value is 1)")
+            prefix <- paste0(index.name, " is out of range, ")
+        if(len != 1)
+            stop0(prefix, "allowed values are 1 to ",  len)
+        else if(treat.NA.as.one)
+            stop0(prefix, "the only allowed value is 1 (or NA)")
+        else
+            stop0(prefix, "the only allowed value is 1")
     }
     index
 }
