@@ -1,10 +1,10 @@
 # prolog.R: plotmo.prolog functions, called at the start of plotmo and plotres
 
-plotmo.prolog <- function(object, env, object.name, ...) # gets called at the start of plotmo
+plotmo.prolog <- function(object, object.name, trace, ...) # gets called at the start of plotmo
 {
     UseMethod("plotmo.prolog")
 }
-plotmo.prolog.default <- function(object, object.name, ...)
+plotmo.prolog.default <- function(object, object.name, trace, ...)
 {
     # prevent confusing downstream errors by doing an initial check here
     if(is.null(object$call) && is.null(object[["x"]]))
